@@ -23,7 +23,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
            force=False, auto_release=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
            file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None,
            notification_endpoint=None, notification_topic=None, notification_events=None,
-           resource_type='OnDemand',
+           resource_type=None,
            nas_access_group=None, nas_file_system=None,
            show_json=False):
 
@@ -198,6 +198,8 @@ def fix_by_opt(desc, opt, check_cluster):
 
         if opt.get('resource_type'):
             task_desc['AutoCluster']['ResourceType'] = opt.get('resource_type')
+        if not task_desc['AutoCluster'].get('ResourceType'):
+            task_desc['AutoCluster']['ResourceType'] = 'OnDemand'
 
 
 
@@ -268,6 +270,9 @@ def extend_mount(desc, mount_m):
                 "WriteSupport": True
             })
 
+
+
+
 def trans_file_to_job_desc(file, check_cluster):
     cf = ConfigParser.ConfigParser()
     # parse file
@@ -276,12 +281,16 @@ def trans_file_to_job_desc(file, check_cluster):
         desc['DAG']['Tasks']['task'] = gen_task_desc()
         return desc
 
+
     # else
     cfg_path = os.path.join(os.getcwd(), file)
     if not os.path.exists(cfg_path):
         raise Exception('Invalid file: %s' % cfg_path)
     cf.read(cfg_path)
 
+    # vars starts with $
+    fit_vars(cf)
+
 
     desc = gen_job_desc()
 
@@ -335,6 +344,7 @@ def trans_file_to_job_desc(file, check_cluster):
             desc['Notification']['Topic']['Name'] = cf.get(sec,'notification_topic')
         if cf.has_option(sec, 'notification_events'):
             desc['Notification']['Topic']['Events'] = trans_notification_events(cf.get(sec,'notification_events'))
+
         #################################
 
         ## extend by default options
@@ -639,6 +649,31 @@ def build_tar_from_arr_and_upload(arr, oss_path):
     oss_client.upload_file( dist, oss_path)
 
 
+######################################
+def fit_vars(cf):
+    secs = cf.sections()
+
+    mKey = {}
+
+
+    for sec in secs:
+        ks = cf.options(sec)
+        for k in ks:
+            if k.startswith('$'):
+                mKey[k]= cf.get(sec, k)
+
+    for sec in secs:
+        ks = cf.options(sec)
+        for k in ks:
+            v =  _ch_vars(mKey, cf.get(sec, k))
+            cf.set(sec, k, v)
+
+def _ch_vars(m, v):
+    for k in m:
+        if k in v:
+            v = v.replace(k, m.get(k))
+    return v
+#########################################
 
 def gen_task_desc():
     cluster_info = trans_cluster(None)
