@@ -1,8 +1,9 @@
-from ..util import result_cache, oss_client, formater, client
+from ..util import result_cache, oss_client, formater, client,smart_unicode
 from terminal import white,green,red,magenta,bold,yellow,blue
 import os
 from oss2.exceptions import NoSuchKey,NoSuchBucket
 import json
+from ..const import WIN,PY2
 
 SLEN = 60
 
@@ -147,7 +148,10 @@ def print_log(taskName, instId, oss_path):
             print('%s [%s:%s, %s:%s]' % (bold((type)), blue('TaskName'),magenta(taskName),blue('InstanceId'), magenta(instId) ))
             print('%s' % white(oss_path))
             print(white('-'*SLEN))
-            print(clor(s))
+            if WIN and PY2:
+                print(smart_unicode.format_utf8(s))
+            else:
+                print(clor(s))
             print(white('-'*SLEN))
 
     except Exception as e:
@@ -158,6 +162,8 @@ def print_log(taskName, instId, oss_path):
 
 
 def download_log(oss_path, dir_path):
+    if not oss_path or oss_path=='':
+        return
     file_name = oss_path[oss_path.rfind('/')+1:]
     print('Download %s' % white(oss_path) )
 
