@@ -2,13 +2,12 @@
 from batchcompute.utils.functions import ConfigError
 from terminal import Logger, prompt, password, green
 
-from ..util import config, client
+from ..util import config, client,util
 
 log = Logger()
 
 
 def login(region, accessKeyId=None, accessKeySecret=None):
-
     opt = config.getConfigs(config.COMMON)
 
     opt['region'] = region
@@ -27,8 +26,15 @@ def login(region, accessKeyId=None, accessKeySecret=None):
 
         config.setConfigs(config.COMMON, opt)
 
+        util.set_default_type_n_image()
+
         print(green('login success' ))
 
-    except ConfigError as e:
-        raise ConfigError('Invalid region %s' % region)
+    except Exception as e:
+        e = '%s' % e
+        if 'nodename nor servname provided' in e:
+            raise Exception('Invalid region %s' % region)
+        else:
+            raise Exception(e)
+
 
